@@ -3,15 +3,20 @@ const char * _session_dbus =
 "<node name=\"/com/canonical/indicator/session/service\">\n"
 "  <interface name=\"com.canonical.indicator.session.service\">\n"
 "\n"
-"    <!-- Icon -->\n"
-"    <method name=\"GetIcon\">\n"
+"    <method name=\"GetUserRealName\">\n"
 "      <arg name=\"name\" direction=\"out\" type=\"s\"/>\n"
 "    </method>\n"
-"\n"
-"    <signal name=\"IconUpdated\">\n"
+"    <method name=\"GetUserMenuVisibility\">\n"
+"      <arg name=\"update\" direction=\"out\" type=\"b\"/>\n"
+"    </method>\n"
+"    <signal name=\"UserRealNameUpdated\">\n"
 "      <arg name=\"name\" type=\"s\"/>\n"
 "    </signal>\n"
-"\n"
+"    <signal name=\"UserMenuIsVisible\">\n"
+"      <arg name=\"update\" type=\"b\"/>\n"
+"    </signal>\n"
+"    <signal name=\"RestartRequired\">\n"
+"    </signal>\n"
 "  </interface>\n"
 "</node>\n"
 ;
